<?php

namespace Merchant\Merchant\Http\Controllers;

use App\Http\Controllers\AdminController as AdminController;
use Former;
use Merchant\Merchant\Http\Requests\MerchantAdminRequest;
use Merchant\Merchant\Interfaces\MerchantRepositoryInterface;
use Response;

/**
 * Admin controller class.
 */
class MerchantAdminController extends AdminController
{
    /**
     * Initialize merchant controller.
     *
     * @param type MerchantRepositoryInterface $merchant
     *
     * @return type
     */
    public function __construct(MerchantRepositoryInterface $merchant)
    {
        $this->model = $merchant;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(MerchantAdminRequest $request)
    {
        if ($request->wantsJson()) {
            $array = $this->model->json();
            foreach ($array as $key => $row) {
                $array[$key] = array_only($row, config('merchant.merchant.listfields'));
            }

            return ['data' => $array];
        }

        $this->theme->prependTitle(trans('merchant::merchant.names').' :: ');

        return $this->theme->of('merchant::admin.merchant.index')->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(MerchantAdminRequest $request, $id)
    {
        $merchant = $this->model->find($id);

        if (empty($merchant)) {
            if ($request->wantsJson()) {
                return [];
            }

            return view('merchant::admin.merchant.new');
        }

        if ($request->wantsJson()) {
            return $merchant;
        }

        Former::populate($merchant);

        return view('merchant::admin.merchant.show', compact('merchant'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(MerchantAdminRequest $request)
    {
        $merchant = $this->model->findOrNew(0);
        Former::populate($merchant);

        return view('merchant::admin.merchant.create', compact('merchant'));
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(MerchantAdminRequest $request)
    {
        try {
            $attributes = $request->all();
            $merchant = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('merchant::merchant.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(MerchantAdminRequest $request, $id)
    {
        $merchant = $this->model->find($id);

        Former::populate($merchant);

        return view('merchant::admin.merchant.edit', compact('merchant'));
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(MerchantAdminRequest $request, $id)
    {
        try {
            $attributes = $request->all();
            $merchant = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('merchant::merchant.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(MerchantAdminRequest $request, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('merchant::merchant.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
